@@ -1,6 +1,6 @@
-poisgamp<-function(y, r, v, ret=FALSE){
-  n<-length(y)
-  y.sum<-sum(y)
+poisgamp = function(y, r, v, ret=FALSE){
+  n = length(y)
+  y.sum = sum(y)
 
   if(is.null(y) || length(y)==0)
     stop("Error: y has no data")
@@ -17,18 +17,23 @@ poisgamp<-function(y, r, v, ret=FALSE){
   cat(paste("Sum of observations:\t", y.sum,"\n\n"))
 
   if(v>0){                              ##proper gamma prior
-    v.inv<-1/v
-    k1<-qgamma(0.9999,r,v)
-    k2<-k1/1000
-    mu<-seq(0,k1, by=k2)
-    r1<-r+y.sum
-    v1<-v+n
-    v1.inv<-1/v1
+    v.inv = 1/v
+    k1 = qgamma(0.9999,r,v)
+    k2 = k1/1000
+    mu = seq(0,k1, by=k2)
+    r1 = r+y.sum
+    v1 = v+n
+    v1.inv = 1/v1
 
-    prior<-dgamma(mu,r, v)
-    posterior<-dgamma(mu, r1, v1)
+    prior = dgamma(mu,r, v)
+    like = matrix(0, nc = length(mu), nr = length(y))
+    for(i in 1:length(mu)){
+        like[,i] = dpois(y,mu[i])
+    }
+    like = apply(like, 2, prod)
+    posterior = dgamma(mu, r1, v1)
 
-    k3<-qgamma(c(0.005,0.995),r1,v1)
+    k3 = qgamma(c(0.005,0.995),r1,v1)
 
     cat("Summary statistics for posterior\n")
     cat("--------------------------------\n")
@@ -36,7 +41,7 @@ poisgamp<-function(y, r, v, ret=FALSE){
     cat(paste("Rate parameter v:\t",v1,"\n"))
     cat(paste("99% credible interval for mu:\t[",round(k3[1],2), ",",round(k3[2],2), "]\n"))
 
-    y.max<-max(prior,posterior)
+    y.max = max(prior,posterior)
     plot(mu,prior,ylim=c(0,1.1*y.max),xlab=expression(mu)
          ,ylab="Density",
          ,main="Shape of gamma prior and posterior for Poisson mean"
@@ -44,14 +49,14 @@ poisgamp<-function(y, r, v, ret=FALSE){
     lines(mu,posterior,lty=3,col="blue")
     legend(mu[1],y.max,lty=2:3,col=c("red","blue"),legend=c("Prior","Posterior"))
   }else if(v==0){
-    r1<-r+y.sum
-    v1<-v+n
-    v1.inv<-1/v1
-    k3<-qgamma(c(0.005,0.995),r1,v1)
-    k4<-k3[2]/1000
-    mu<-seq(0,k3[2],by=k4)
+    r1 = r+y.sum
+    v1 = v+n
+    v1.inv = 1/v1
+    k3 = qgamma(c(0.005,0.995),r1,v1)
+    k4 = k3[2]/1000
+    mu = seq(0,k3[2],by=k4)
 
-    mu[1]<-mu[2] ## fixes infinite upper bound problem
+    mu[1] = mu[2] ## fixes infinite upper bound problem
 
     cat("Summary statistics for posterior\n")
     cat("--------------------------------\n")
@@ -59,12 +64,19 @@ poisgamp<-function(y, r, v, ret=FALSE){
     cat(paste("Rate parameter v:\t",v1,"\n"))
     cat(paste("99% credible interval :\t[",round(k3[1],2),", ",round(k3[2],2), "]\n"))
 
-    prior<-mu^(r-1)
-    kint<-(2*sum(prior)-prior[1001])*k4/2
-    prior<-prior/kint
-    posterior<-dgamma(mu, r1, v1)
+    prior = mu^(r-1)
+    kint = (2*sum(prior)-prior[1001])*k4/2
+    prior = prior/kint
 
-    y.max<-max(prior,posterior)
+    like = matrix(0, nc = length(mu), nr = length(y))
+    for(i in 1:length(mu)){
+        like[,i] = dpois(y,mu[i])
+    }
+    like = apply(like, 2, prod)
+
+    posterior = dgamma(mu, r1, v1)
+
+    y.max = max(prior,posterior)
     plot(mu,prior,ylim=c(0,1.1*y.max),xlab=expression(mu)
          ,ylab="Density",
          ,main="Shape of gamma prior and posterior for Poisson mean"
@@ -74,8 +86,13 @@ poisgamp<-function(y, r, v, ret=FALSE){
   }else{
     stop("Error: v must be greater or equal to zero")
   }
-  if(ret)
-    return(list(r=r1,v=v1,mu=mu,prior=prior,posterior=posterior))
+
+  if(ret){
+      cat("The argument ret is deprecated.\n")
+      cat("The results are now always returned invisibly\n")
+  }
+
+  invisible(list(r=r1,v=v1,mu=mu,prior=prior,likelihood = like, posterior=posterior))
 }
 
 
